#!/usr/bin/perl -w

##################################################################
#
# SOLpro:       Protein Solubility Predictor
# configure.pl: to configure the installation of SOLpro
#
# Author: Christophe N. Magnan
# Last modification: April 14, 2009
# Institute for Genomics and Bioinformatics
# University of California, Irvine
# Email: cmagnan@ics.uci.edu
#
##################################################################

##################################################################
#
#                 Customize settings here
#
# set installation directory of SSpro 4.0 (absolute path)
$sspro_dir = "/home/.../sspro4/";
#
# set installation directory of DOMpro 1.0 (absolute path)
$dompro_dir = "/home/.../dompro/";
#
# set installation directory of SOLpro (absolute path)
$solpro_dir = "/home/.../solpro/";
#
##################################################################

##################################################################
#                                                                #
#                Don't modify the code below                     #
#                                                                #
##################################################################

# check installation of SSpro 4.0
if(substr($sspro_dir,length($sspro_dir)-1,1) ne "/"){ $sspro_dir .= "/";  }
if(! -d $sspro_dir){ die "Can't find SSpro 4.0 installation directory.\n"; }
$sspro_sh  = "${sspro_dir}bin/predict_ssa.sh";
$accpro_sh = "${sspro_dir}bin/predict_acc.sh";
if(! -f $sspro_sh || ! -f $accpro_sh){ die "SSpro 4.0 is not correctly installed\n"; }

# check installation of DOMpro 1.0
if(substr($dompro_dir,length($dompro_dir)-1,1) ne "/"){ $dompro_dir .= "/";  }
if(! -d $dompro_dir){ die "Can't find DOMpro 1.0 installation directory.\n"; }
$dompro_sh = "${dompro_dir}bin/predict_dom.sh";
if(! -f $dompro_sh){ die "DOMpro 1.0 is not correctly installed\n"; }

# check installation directory of SOLpro
if(substr($solpro_dir,length($solpro_dir)-1,1) ne "/"){ $solpro_dir .= "/";  }
if(! -d $solpro_dir){ die "Can't find SOLpro installation directory.\n"; }

# directories in the package
$bin_dir = "${solpro_dir}bin/";
$models_dir = "${solpro_dir}models/";
$scripts_dir = "${solpro_dir}scripts/";
$test_dir = "${solpro_dir}test/";
$tmp_dir = "${solpro_dir}tmp/";

# check the directories in the package
if(! -d $bin_dir || ! -d $models_dir || ! -d $scripts_dir || ! -d $test_dir || ! -d $tmp_dir)
{ die "Some subdirectories of SOLpro don't exist. Check the installation tar ball.\n"; }

# check the files in the package
@feat = ("01","02","03","04","05","06","07","08","09","10","11","12","13","14","15","16","17","18","19","20","21");
for $i (0..$#feat)
{ if(! -f "${models_dir}FeatSet$feat[$i].model" || ! -f "${models_dir}FeatSet$feat[$i].range")
  { die "Some files in the solpro package are not found. Please check the installation tar ball.\n"; } }
$features1_c = "${scripts_dir}features1.c";
$features2_c = "${scripts_dir}features2.c";
$solpro_pl = "${scripts_dir}predict_sol.pl";
if(! -f $features1_c || ! -f $features2_c || ! -f $solpro_pl)
{ die "Some files in the solpro package are not found. Please check the installation tar ball.\n"; }

# check libsvm files
if(! -f "${bin_dir}svm-predict" || ! -f "${bin_dir}svm-scale")
{ die "Please copy the svm-predict and svm-scale files of LibSVM into the solpro directory bin\n"; }

# missing scripts
$solpro_sh = "${bin_dir}predict_sol.sh";
$features1 = "${bin_dir}features1";
$features2 = "${bin_dir}features2";

# create predict_sol.sh script
open(SOLPRO_SH,">$solpro_sh") || die "Can't write SOLpro shell script.\n";
print SOLPRO_SH "#!/bin/sh\n#predict solubility for one sequence.\n";
print SOLPRO_SH "if [ \$# -ne 2 ]\nthen\n\techo \"need 2 parameters: ";
print SOLPRO_SH "fasta_file, output file.\"\n\texit 1\nfi\n";
print SOLPRO_SH "$solpro_pl $sspro_sh $accpro_sh $dompro_sh ";
print SOLPRO_SH "$bin_dir $models_dir $tmp_dir \$1 \$2 \n";
close SOLPRO_SH;

# create features1 and features2 scripts
`gcc -Wall -lm -o $features1 $features1_c`;
`gcc -Wall -lm -o $features2 $features2_c`;

# check scripts
if(! -f $solpro_sh || ! -f $features1 || ! -f $features2)
{ die "Installation failed. Please install \"gcc\" compiler.\n"; }

# end
`chmod -R 755 ${solpro_dir}*`;
print "done...\n";
