/*********************************************************************

    SCRIPT:             features2.c
    LAST_MODIFICATION:  04/14/2009
    AUTHOR:             Christophe Nicolas Magnan
    CONTACT:            cmagnan@ics.uci.edu

    SHORT DESCRIPTION:  This script computes the features for
                        the second step of SOLpro

*********************************************************************/

/** Preprocessing **/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#define SIZE_SEQ 2010
#define SIZE_PATH 300

/** Global Variables: Files and script parameters **/
char FileIN[SIZE_PATH];			// Script parameter
char FileOUT[SIZE_PATH];		// Current output file
FILE * in, * out;			// File descriptors

/** Global Variables: Protein Features **/
char SEQ[SIZE_SEQ];			// Primary sequence
int Len;				// Sequence length
double Pred[20];			// Predictions of the 20 models

/** Functions included at the end of this script **/
void Initialize_Protein_Features();
void Check_Script_Parameter();
void Read_Input_File();
void Read_Predictions();
void Print_Features();

/** Main function **/
int main(int argc, char *argv[])
{
  /** Statistics Initialization **/
  Initialize_Protein_Features();

  /** Script parameters **/
  if(argc!=2){ exit(0); }
  strcpy(FileIN,argv[1]);
  Check_Script_Parameter();
  
  /** Input files parsing **/
  Read_Input_File();
  Read_Predictions();
  
  /** Output file **/
  Print_Features();
  
  /** End of the script **/
  return 0;
}

/** Functions **/
void Clean_Array(char * a,int b,int l)
{
  int i; for(i=b;i<l;i++){ a[i]='\0'; }
}

int Is_Sep(char c)
{
  if((c==' ')||(c=='\n')||(c=='\r')||(c=='\t')){ return 1; } return 0;
}

void Print_Features()
{
  int i; sprintf(FileOUT,"%s21",FileIN);
  if((out=fopen(FileOUT,"w"))==NULL){ exit(0); }
  fprintf(out,"0 1:%d ",Len);
  for(i=0;i<20;i++){ fprintf(out,"%d:%.6f ",i+2,Pred[i]); }
  fprintf(out,"\n"); fclose(out);
}

void Read_Prediction(char * name, int index)
{
  char Input[SIZE_PATH], c; int class;
  sprintf(Input,"%s%s.pred",FileIN,name);
  if((in=fopen(Input,"r"))==NULL){ exit(0); }
  c='a'; while(c!='\n'){ c=fgetc(in); }
  fscanf(in,"%d",&class); fscanf(in,"%lf",&Pred[index]); fclose(in);
}

void Read_Predictions()
{
  Read_Prediction("01",0);  Read_Prediction("02",1);
  Read_Prediction("03",2);  Read_Prediction("04",3);
  Read_Prediction("05",4);  Read_Prediction("06",5);
  Read_Prediction("07",6);  Read_Prediction("08",7);
  Read_Prediction("09",8);  Read_Prediction("10",9);
  Read_Prediction("11",10); Read_Prediction("12",11);
  Read_Prediction("13",12); Read_Prediction("14",13);
  Read_Prediction("15",14); Read_Prediction("16",15);
  Read_Prediction("17",16); Read_Prediction("18",17);
  Read_Prediction("19",18); Read_Prediction("20",19);
}

void Read_Input_File()
{
  int i=0; char c;
  if((in=fopen(FileIN,"r"))==NULL){ exit(0); } c=fgetc(in);
  while((c!='\n')&&(c!=EOF))
  { if(!Is_Sep(c)){ SEQ[i]=toupper(c); i++; } c=fgetc(in); }
  Clean_Array(SEQ,i,SIZE_SEQ); Len=strlen(SEQ); fclose(in);
}

void Check_Script_Parameter()
{
  if((FileIN[0]!='/')||(FileIN[1]!='h')){ exit(0); }
}

void Initialize_Protein_Features()
{ 
  int i; Len=0;
  for(i=0;i<SIZE_SEQ;i++){ SEQ[i]='\0'; }
  for(i=0;i<20;i++){ Pred[i]=0.; }
}
